@@ -53,4 +53,4 @@ class Config:
             return self.config.get(section="GITLAB", option=GitProject.git_host())
         else:
             raise GitLabLoginException(
-                f"You need login to git server {self.git_project.git_project_url()}. Use git-login command!")
+                f"You need login to git server {GitProject.git_project_url()}. Use git-login command!")
